bayespy.inference.vmp.nodes.poisson.PoissonMoments.get_converter
================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.poisson

.. automethod:: PoissonMoments.get_converter